km3modules.common.Delete
========================

.. currentmodule:: km3modules.common

.. autoclass:: Delete

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Delete.__init__
      ~Delete.add
      ~Delete.configure
      ~Delete.expose
      ~Delete.finish
      ~Delete.get
      ~Delete.pre_finish
      ~Delete.process
      ~Delete.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Delete.name
   
   